﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using Infragistics.Windows;
using Infragistics.Windows.DataPresenter;
using System.ComponentModel;
using Infragistics.Windows.Editors;
using System.Diagnostics;

namespace RecordEditing
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window, INotifyPropertyChanged
    {
        private Dictionary<string, object> values;
        public event PropertyChangedEventHandler PropertyChanged;
        private bool isEditing;

        public MainWindow()
        {
            InitializeComponent();
           
            values = new Dictionary<string, object>();
        }

        private void edit_btn_Click(object sender, RoutedEventArgs e)
        {
            XamDataGrid grid = Utilities.GetAncestorFromType(sender as Button, typeof(XamDataGrid), false) as XamDataGrid;
            grid.ExecuteCommand(DataPresenterCommands.CellFirstInRecord);
            grid.ExecuteCommand(DataPresenterCommands.StartEditMode);

            IsCurrenlyEditing = true;
        }

        private void save_btn_Click(object sender, RoutedEventArgs e)
        {
            IsCurrenlyEditing = false;
            values.Clear();
        }

        private void cancel_btn_Click(object sender, RoutedEventArgs e)
        {
            IsCurrenlyEditing = false;

            CellValuePresenter cvp = Utilities.GetAncestorFromType(sender as DependencyObject, typeof(CellValuePresenter), false) as CellValuePresenter;
            if (cvp != null)
            {
                foreach (KeyValuePair<string, object> item in values)
                {
                    cvp.Record.Cells[item.Key].Value = item.Value;
                    cvp.EndEditMode(true, true);
                }
            }

            values.Clear();
        }

        public bool IsCurrenlyEditing 
        {
            get { return isEditing; }
            set
            {
                isEditing = value;

                if (PropertyChanged != null)
                {
                    PropertyChanged(this, new PropertyChangedEventArgs("IsCurrenlyEditing"));
                }
            }
        }

        private void xamDataGrid1_RecordActivating(object sender, Infragistics.Windows.DataPresenter.Events.RecordActivatingEventArgs e)
        {
            if (e.Record is DataRecord)
            {
                ClearTags((sender as XamDataGrid).Records);
                e.Record.Tag = "Active";
            }
        }

        private void ClearTags(RecordCollectionBase records)
        {
            foreach (Record record in records)
            {
                if (record is DataRecord)
                {
                    record.Tag = null;
                }

                if (record is GroupByRecord)
                {
                    ClearTags((record as GroupByRecord).ChildRecords);
                }
            }
        }

        private void xamDataGrid1_EditModeStarted(object sender, Infragistics.Windows.Editors.Events.EditModeStartedEventArgs e)
        {
            CellValuePresenter cvp = Utilities.GetAncestorFromType(sender as DependencyObject, typeof(CellValuePresenter), false) as CellValuePresenter;
            if (cvp != null)
            {
                IsCurrenlyEditing = true;

                if (!values.ContainsKey(cvp.Field.Name))
                {
                    values.Add(cvp.Field.Name, (sender as ValueEditor).Value);
                }
            } 
        }
    }

    public class GridItemCollection : ObservableCollection<GridItem>
    {
        public GridItemCollection()
        {
            Add(new GridItem
            {
                ID = 1,
                Name = "John",
                DateOfBirth = new DateTime(1989, 4, 4),
                Country = "Bulgaria",
                City = "Sofia",
                Salary = 1000.00
            }); 
            
            Add(new GridItem
            {
                ID = 2,
                Name = "Steve",
                DateOfBirth = new DateTime(1929, 12, 12),
                Country = "Bulgaria",
                City = "Plovdiv",
                Salary = 1000.00
            }); 
            
            Add(new GridItem
            {
                ID = 3,
                Name = "Nick",
                DateOfBirth = new DateTime(1944, 9, 14),
                Country = "Bulgaria",
                City = "Plovdiv",
                Salary = 2200.00
            }); 
            
            Add(new GridItem
            {
                ID = 4,
                Name = "Josephine",
                DateOfBirth = new DateTime(1999, 5, 4),
                Country = "Bulgaria",
                City = "Sofia",
                Salary = 2000.00
            });

            Add(new GridItem
            {
                ID = 5,
                Name = "Adam",
                DateOfBirth = new DateTime(1992, 7, 9),
                Country = "Bulgaria",
                City = "Varna",
                Salary = 1500.00
            });
        }
    }

    public class GridItem
    {
        public int ID { get; set; }
        public string Name { get; set; }
        public string City { get; set; }
        public double Salary { get; set; }
        public string Country { get; set; }
        public DateTime DateOfBirth { get; set; }
    }
}
